![Logo Dark](docs/source/_static/MolFlux_logo_final_MolFlux%20logo%20name-cropped.svg#gh-dark-mode-only)
![Logo Light](docs/source/_static/MolFlux_logo_final_MolFlux%20logo%20name%20Grey-cropped.svg#gh-light-mode-only)

---

[![PyPI version](https://img.shields.io/pypi/v/molflux)](https://pypi.org/project/molflux/)
[![Supported Python versions](https://img.shields.io/badge/python-3.10%20%7C%203.11-blue.svg)](https://docs.python.org/3/whatsnew/index.html)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/charliermarsh/ruff)
[![Checked with mypy](https://img.shields.io/badge/mypy-checked-blue)](http://mypy-lang.org/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

---

## What is MolFlux?

MolFlux is a foundational package for molecular predictive modelling. From data to features to models, MolFlux provides
you with a complete ecosystem for building and handling machine learning models!

## Installation
### With pip

```bash
pip install molflux
```

#### Optional Dependencies

Some functionalities in `molflux` require additional dependencies, which you can install as needed. For example

```bash
pip install molflux[rdkit]
```

## Documentation

To learn more about how to use ``molflux``, see the [documentation](https://exscientia.github.io/molflux/).

## Contribution guidelines

Anyone is welcome to submit PRs for new functionality or fixes! Just create a pull request and we will review and get back to
you.

## License
[MIT License](LICENSE)

## Acknowledgements

The ``molflux`` package has been developed by researchers and engineers at Exscientia

* Alan Bilsland
* Giovanni Bocci
* [Julia Buhmann](https://github.com/juliabuhmann)
* [Ward Haddadin](https://github.com/wardhaddadin1)
* Jonathan Harrison
* Henry Kenlay
* Dom Miketa
* Emil Nichita
* Stefanie Speichert
* Hagen Triendl
* [Alvise Vianello](https://github.com/amv213)
* Andy Wedlake
